==> vue-element-ui-plus-1.0.95.tgz: package/test/index.js <==
import Vue from 'vue'
import App from './App'
import moment from 'moment'
// import ElementUI from 'element-ui'
import VueElementUiPlus from '../src/index'
// import VueElementUiPlus from '../lib/vue-element-ui-plus.common'
// import VueElementUiPlus from '../lib/index'
// import Table from '../lib/table'
import '../theme-chalk/index.scss'
import './icons/index'
import { uploadFiles } from './api'


Vue.use(VueElementUiPlus, {
    size: 'small',
    pagination: { pageSizes: [10, 20, 50, 100] },
    title: {
        prefix: 'plus'
    },
    button: {
        isProxy: true,
        proxyList: [
            {
                name: '删除',
                message: '确认要删除这条数据吗？'
            },
        ]
    },
    form: {
        searchFlex: true,
        placeholder: true,
        position: true
    },
    formContent: {
        format(value, format) {
            if (format == 'yyyy-MM-dd') {
                format = 'YYYY-MM-DD'
            }
            return moment(value).format(format)
        }
    },
    select: {
        getOptions() {
            return [
                { label: 'a', id: '1' },
                { label: 'b', id: '2' },
                { label: 'c', id: '3' },
                { label: 'd', id: '4' },
            ]
        }
    },
    table: {
        stripe: true,
        maxHeightAuto: true,
    },
    tableColumn: {
        showOverflowTooltip: true
    },
    drawer: {
        footer: false,
        showCancelButton: true,
        showConfirmButton: true,
    },
    upload: {
        name: 'files',
        // action: ''
        // autoUpload: false,
        httpRequest(options) {
            let formData = new FormData()
            formData.append(this.name, options.file)
            if (this.data) {
                this.data.forEach(key => {
                    formData.append(key, this.data[key])
                })
            }
            return uploadFiles(formData, options.onProgress)
        }
    }
})

// Vue.use(Table)
sessionStorage.setItem("token", "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJsaWNlbnNlIjoic28tZmFzdCIsInVzZXJfbmFtZSI6InN5c19hZG1pbiIsInNjb3BlIjpbInJlYWQiLCJ3cml0ZSJdLCJleHAiOjE2Nzc0MjQ5MTAsInVzZXJOYW1lIjoic3lzX2FkbWluIiwidXNlcklkIjozNywiYXV0aG9yaXRpZXMiOlsiYWRtaW4iLCJkZXZpY2VNYW5hZ2VyIiwiSFJBIl0sImp0aSI6IjA5ZjViYTIxLWI0M2YtNGIzOC05NmE4LWUwZGU3ZmUxZDM3YyIsIm9yZ0lkIjoxLCJjbGllbnRfaWQiOiJ3ZWIifQ.0PUTK37dX8XN1rHMmbBQD5souqyBc4njIUFzHPly2cc");

new Vue({
    render: h => h(App)
}).$mount('#app')

==> vue-element-ui-plus-1.0.97.tgz: package/test/index.js <==
import Vue from 'vue'
import App from './App'
import moment from 'moment'
// import ElementUI from 'element-ui'
import VueElementUiPlus from '../src/index'
// import VueElementUiPlus from '../lib/vue-element-ui-plus.common'
// import VueElementUiPlus from '../lib/index'
// import Table from '../lib/table'
import '../theme-chalk/index.scss'
import './icons/index'
import { uploadFiles } from './api'


Vue.use(VueElementUiPlus, {
    size: 'small',
    pagination: { pageSizes: [10, 20, 50, 100] },
    title: {
        prefix: 'plus'
    },
    button: {
        isProxy: true,
        proxyList: [
            {
                name: '删除',
                message: '确认要删除这条数据吗？'
            },
        ]
    },
    form: {
        searchFlex: true,
        placeholder: true,
        position: true
    },
    formContent: {
        format(value, format) {
            if (format == 'yyyy-MM-dd') {
                format = 'YYYY-MM-DD'
            }
            return moment(value).format(format)
        }
    },
    select: {
        getOptions() {
            return [
                { label: 'a', id: '1' },
                { label: 'b', id: '2' },
                { label: 'c', id: '3' },
                { label: 'd', id: '4' },
            ]
        }
    },
    table: {
        stripe: true,
        maxHeightAuto: true,
    },
    tableColumn: {
        showOverflowTooltip: true
    },
    drawer: {
        footer: false,
        showCancelButton: true,
        showConfirmButton: true,
    },
    upload: {
        name: 'files',
        // action: ''
        // autoUpload: false,
        httpRequest(options) {
            let formData = new FormData()
            formData.append(this.name, options.file)
            if (this.data) {
                this.data.forEach(key => {
                    formData.append(key, this.data[key])
                })
            }
            return uploadFiles(formData, options.onProgress)
        },
        download(file) {
            console.log(file)
        }
    }
})

// Vue.use(Table)
sessionStorage.setItem("token", "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJsaWNlbnNlIjoic28tZmFzdCIsInVzZXJfbmFtZSI6ImFkbWluIiwic2NvcGUiOlsicmVhZCIsIndyaXRlIl0sImV4cCI6MTY3OTMyMDgzOCwidXNlck5hbWUiOiJhZG1pbiIsInVzZXJJZCI6MSwiYXV0aG9yaXRpZXMiOlsidGVzdEFwcEFkbWluIiwic2VydmljZU1hbmFnZUFkbWluIiwiZGVtb18yMCIsIkhSQSIsInNhZmV0eVN1cGVydmlzaW9uQWRtaW4iLCJxdWFsaXR5TWFuYWdlQWRtaW4iLCJkZXZpY2UiLCJzcGFjZSJdLCJqdGkiOiI2ZWRkYTM4Yi0zODc3LTQ3MGUtODY4NC0xMDAyNmQ2ZTEwOWUiLCJvcmdJZCI6MSwiY2xpZW50X2lkIjoid2ViIn0.kBVx3jZSYMw29WXR-CtXYej5Day128-C21HQRI7BZ1c");

new Vue({
    render: h => h(App)
}).$mount('#app')
